Struct Covariates
pub struct Covariates { /* private fields */ }Expand description
A collection of Covariates
This struct provides methods to manage multiple covariates and retrieve interpolated values for all covariates at specific time points.
Implementations
impl Covariates
impl Covariates
pub fn new() -> Covariates
pub fn new() -> Covariates
Create a new empty collection of covariates
pub fn covariates(&self) -> HashMap<String, &Covariate>
pub fn covariates(&self) -> HashMap<String, &Covariate>
Get all covariates in this collection
pub fn hash(&self) -> u64
pub fn hash(&self) -> u64
Produce a content-based hash of all covariates.
The internal BTreeMap guarantees deterministic iteration order.
pub fn add_covariate(&mut self, name: String, covariate: Covariate)
pub fn add_covariate(&mut self, name: String, covariate: Covariate)
Add a covariate to the collection
This method allows you to add a new covariate with a specific name and its associated data.
pub fn get_covariate(&self, name: &str) -> Option<&Covariate>
pub fn get_covariate(&self, name: &str) -> Option<&Covariate>
Get access to a specific covariate by name
pub fn get_covariate_mut(&mut self, name: &str) -> Option<&mut Covariate>
pub fn get_covariate_mut(&mut self, name: &str) -> Option<&mut Covariate>
Get access to a specific covariate by name
pub fn remove_covariate(&mut self, name: &str) -> Option<Covariate>
pub fn remove_covariate(&mut self, name: &str) -> Option<Covariate>
Remove a covariate by name
pub fn add_observation(&mut self, name: &str, time: f64, value: f64)
pub fn add_observation(&mut self, name: &str, time: f64, value: f64)
Add an observation to a covariate, creating the covariate if it doesn’t exist
If a value already exists at the specified time, it will update that value silently
pub fn update_observation(
&mut self,
name: &str,
time: f64,
new_value: f64,
) -> bool
pub fn update_observation( &mut self, name: &str, time: f64, new_value: f64, ) -> bool
Update an observation for a specific covariate
pub fn remove_observation(&mut self, name: &str, time: f64) -> bool
pub fn remove_observation(&mut self, name: &str, time: f64) -> bool
Remove an observation from a specific covariate
pub fn set_covariate_fixed(&mut self, name: &str, fixed: bool) -> bool
pub fn set_covariate_fixed(&mut self, name: &str, fixed: bool) -> bool
Set a covariate as fixed (use carry-forward interpolation)
This is a common operation in pharmacokinetic modeling where you want to treat a covariate as constant.
pub fn to_hashmap(
&mut self,
time: f64,
) -> Result<HashMap<String, f64>, CovariateError>
pub fn to_hashmap( &mut self, time: f64, ) -> Result<HashMap<String, f64>, CovariateError>