Struct Subject
pub struct Subject { /* private fields */ }Expand description
A subject in a pharmacometric dataset
A Subject represents a single individual with one or more occasions of data, each containing events (doses, observations) and covariates.
Implementations
impl Subject
impl Subject
pub fn occasions(&self) -> &[Occasion]
pub fn occasions(&self) -> &[Occasion]
Get a vector of references to all occasions for this subject
Returns
A slice of all occasions for this subject
pub fn from_occasions(id: String, occasions: Vec<Occasion>) -> Subject
pub fn from_occasions(id: String, occasions: Vec<Occasion>) -> Subject
Create a new subject from one or more occasions
This is useful when you want to create a subject from specific occasions rather than building it completely from scratch.
Arguments
id- The subject identifieroccasions- Vector of occasions to include in this subject
Returns
A new subject containing the specified occasions
pub fn occasions_mut(&mut self) -> &mut Vec<Occasion>
pub fn occasions_mut(&mut self) -> &mut Vec<Occasion>
Iterate over a mutable reference to the occasions
pub fn occasions_iter_mut(&mut self) -> IterMut<'_, Occasion>
pub fn occasions_iter_mut(&mut self) -> IterMut<'_, Occasion>
Get a mutable iterator to the occasions
pub fn get_output_equations(&self) -> Vec<usize>
pub fn get_occasion_mut(&mut self, index: usize) -> Option<&mut Occasion>
pub fn get_occasion_mut(&mut self, index: usize) -> Option<&mut Occasion>
pub fn iter_mut(&mut self) -> IterMut<'_, Occasion>
pub fn iter_mut(&mut self) -> IterMut<'_, Occasion>
Get a mutable iterator over all occasions
Returns
A mutable iterator yielding references to occasions
impl Subject
impl Subject
pub fn nca_with_dose(
&self,
dose_amount: f64,
route: Route,
infusion_duration: Option<f64>,
options: &NCAOptions,
) -> Result<NCAResult, NCAError>
pub fn nca_with_dose( &self, dose_amount: f64, route: Route, infusion_duration: Option<f64>, options: &NCAOptions, ) -> Result<NCAResult, NCAError>
Run NCA with an explicit dose on the first occasion, overriding what is embedded in the subject’s events.
Use this when you want to supply or override dose amount, route, or infusion duration without modifying the underlying data.